@@ -25,6 +25,6 @@ class ZabbixAgent:
         try:
             result = self.sender.send([ZabbixMetric(host=host, key=key, value=value)])
         except Exception as ex:
-            result = {}
+            result = {'error': str(ex)}
         logger.get_logger().log_debug(result)
         return result
